#ifdef __BLOCKS__
#undef __BLOCKS__
#endif
#include <librsvg/rsvg.h>
#include <librsvg/rsvg-cairo.h>
#include <librsvg/librsvg-features.h>
